@@ -17,7 +17,6 @@ from argparse import ArgumentParser
 
 import ldap
 
-import univention
 import univention.connector
 import univention.connector.ad
 from univention.config_registry import ConfigRegistry
@@ -38,14 +37,14 @@ def daemon(lock_file, options):
     except OSError as e:
         print(f'Daemon Mode Error: {e.strerror}')
 
-    if (pid == 0):
+    if pid == 0:
         os.setsid()
         signal.signal(signal.SIGHUP, signal.SIG_IGN)
         try:
             pid = os.fork()
         except OSError as e:
             print(f'Daemon Mode Error: {e.strerror}')
-        if (pid == 0):
+        if pid == 0:
             os.chdir("/")
             os.umask(0o027)
         else:
