@@ -3,37 +3,15 @@
 # Univention AD Connector
 #  Mapping functions for proxyAddresses
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2016-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2016-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
-import univention.debug2 as ud
+from logging import getLogger
+
+from univention.logging import Structured
+
+
+log = Structured(getLogger("LDAP").getChild(__name__))
 
 
 def valid_mailaddress(val):
@@ -60,8 +38,8 @@ def equal(values1, values2):
     1. in sync_from_ucs: values1 are mapped ucs and values2 are        con
     2. in __set_values:  values1 are        ucs and values2 are mapped con
     """
-    ud.debug(ud.LDAP, ud.ALL, "proxyAddesses: values1: %r" % (values1,))
-    ud.debug(ud.LDAP, ud.ALL, "proxyAddesses: values2: %r" % (values2,))
+    log.trace("proxyAddesses: values1: %r", values1)
+    log.trace("proxyAddesses: values2: %r", values2)
     values_normalized = []
     for values in (values1, values2):
         if not isinstance(values, list | tuple):
